@@ -99,6 +99,7 @@ static const char * const sort_order_values[] =
     "name",
     "directory",
     "size",
+    "size_on_disk",
     "type",
     "mtime",
     "atime",
@@ -221,9 +222,9 @@ preferences_show_help (GtkWindow *parent,
 
     help_string = g_strdup_printf ("help:%s/%s", helpfile, sect_id);
 
-    gtk_show_uri (gtk_window_get_screen (parent),
-                  help_string, gtk_get_current_event_time (),
-                  &error);
+    gtk_show_uri_on_window (parent,
+                            help_string, gtk_get_current_event_time (),
+                            &error);
     g_free (help_string);
 
     if (error)
@@ -625,10 +626,11 @@ extension_about_clicked (GtkButton *button, Extension *ext)
     gtk_about_dialog_set_comments (extension_about_dialog, ext->description);
     gtk_about_dialog_set_logo_icon_name (extension_about_dialog, ext->icon != NULL ? ext->icon : "system-run");
     gtk_about_dialog_set_copyright (extension_about_dialog, ext->copyright);
-    gtk_about_dialog_set_authors (extension_about_dialog, ext->author);
+    gtk_about_dialog_set_authors (extension_about_dialog, (const gchar **) ext->author);
     gtk_about_dialog_set_version (extension_about_dialog, ext->version);
     gtk_about_dialog_set_website (extension_about_dialog, ext->website);
     gtk_window_set_title (GTK_WINDOW(extension_about_dialog), _("About Extension"));
+    gtk_window_set_icon_name (GTK_WINDOW(extension_about_dialog), ext->icon != NULL ? ext->icon : "system-run");
     gtk_dialog_run (GTK_DIALOG (extension_about_dialog));
     gtk_widget_destroy (GTK_WIDGET (extension_about_dialog));
 }
@@ -733,7 +735,7 @@ caja_file_management_properties_dialog_setup_media_page (GtkBuilder *builder)
         GIcon *icon;
         CajaIconInfo *icon_info;
         GdkPixbuf *pixbuf;
-        int icon_size;
+        int icon_size, icon_scale;
 
         if (!g_str_has_prefix (content_type, "x-content/"))
             continue;
@@ -746,13 +748,14 @@ caja_file_management_properties_dialog_setup_media_page (GtkBuilder *builder)
         }
 
         icon_size = caja_get_icon_size_for_stock_size (GTK_ICON_SIZE_MENU);
+        icon_scale = gtk_widget_get_scale_factor (other_type_combo_box);
 
         description = g_content_type_get_description (content_type);
         gtk_list_store_append (other_type_list_store, &iter);
         icon = g_content_type_get_icon (content_type);
         if (icon != NULL)
         {
-            icon_info = caja_icon_info_lookup (icon, icon_size);
+            icon_info = caja_icon_info_lookup (icon, icon_size, icon_scale);
             g_object_unref (icon);
             pixbuf = caja_icon_info_get_pixbuf_nodefault_at_size (icon_info, icon_size);
             g_object_unref (icon_info);
