@@ -44,6 +44,7 @@
 #include <glib/gi18n.h>
 #include <eel/eel-gtk-extensions.h>
 #include <libcaja-extension/caja-menu-provider.h>
+#include <libcaja-private/caja-extensions.h>
 #include <libcaja-private/caja-file-utilities.h>
 #include <libcaja-private/caja-global-preferences.h>
 #include <libcaja-private/caja-icon-names.h>
@@ -60,7 +61,6 @@
 
 #define NETWORK_URI          "network:"
 #define COMPUTER_URI         "computer:"
-#define BURN_CD_URI          "burn:"
 
 /* Struct that stores all the info necessary to activate a bookmark. */
 typedef struct
@@ -98,8 +98,11 @@ bookmark_holder_new (CajaBookmark *bookmark,
 static void
 bookmark_holder_free (BookmarkHolder *bookmark_holder)
 {
+    if (g_signal_handler_is_connected(bookmark_holder->bookmark,
+                                      bookmark_holder->changed_handler_id)){
     g_signal_handler_disconnect (bookmark_holder->bookmark,
-                                 bookmark_holder->changed_handler_id);
+                                      bookmark_holder->changed_handler_id);
+    }
     g_object_unref (bookmark_holder->bookmark);
     g_free (bookmark_holder);
 }
@@ -172,7 +175,7 @@ caja_menus_append_bookmark_to_menu (CajaWindow *window,
     char action_name[128];
     char *name;
     char *path;
-    GdkPixbuf *pixbuf;
+    cairo_surface_t *surface;
     GtkAction *action;
     GtkWidget *menuitem;
 
@@ -182,8 +185,8 @@ caja_menus_append_bookmark_to_menu (CajaWindow *window,
     bookmark_holder = bookmark_holder_new (bookmark, window, refresh_callback, failed_callback);
     name = caja_bookmark_get_name (bookmark);
 
-    /* Create menu item with pixbuf */
-    pixbuf = caja_bookmark_get_pixbuf (bookmark, GTK_ICON_SIZE_MENU);
+    /* Create menu item with surface */
+    surface = caja_bookmark_get_surface (bookmark, GTK_ICON_SIZE_MENU);
 
     g_snprintf (action_name, sizeof (action_name), "%s%d", parent_id, index_in_parent);
 
@@ -193,8 +196,8 @@ caja_menus_append_bookmark_to_menu (CajaWindow *window,
                              NULL);
 
     g_object_set_data_full (G_OBJECT (action), "menu-icon",
-                            g_object_ref (pixbuf),
-                            g_object_unref);
+                            cairo_surface_reference (surface),
+                            cairo_surface_destroy);
 
     g_signal_connect_data (action, "activate",
                            G_CALLBACK (activate_bookmark_in_menu_item),
@@ -220,7 +223,7 @@ caja_menus_append_bookmark_to_menu (CajaWindow *window,
     gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menuitem),
             TRUE);
 
-    g_object_unref (pixbuf);
+    cairo_surface_destroy (surface);
     g_free (path);
     g_free (name);
 }
@@ -535,7 +538,7 @@ action_about_caja_callback (GtkAction *action,
                                          "files and folders, both on "
                                          "your computer and online."),
                            "copyright", _("Copyright \xC2\xA9 1999-2009 The Nautilus authors\n"
-                                          "Copyright \xC2\xA9 2011-2013 The Caja authors"),
+                                          "Copyright \xC2\xA9 2011-2018 The Caja authors"),
                            "license", license_trans,
                            "wrap-license", TRUE,
                            "authors", authors,
@@ -572,40 +575,11 @@ action_caja_manual_callback (GtkAction *action,
     error = NULL;
     window = CAJA_WINDOW (user_data);
 
-    if (CAJA_IS_DESKTOP_WINDOW (window))
-    {
-#if GTK_CHECK_VERSION (3, 0, 0)
-        GdkScreen *screen;
-        GdkAppLaunchContext *launch_context;
-        GAppInfo *app_info = NULL;
-        app_info = g_app_info_create_from_commandline ("mate-help",
-                                                       NULL,
-                                                       G_APP_INFO_CREATE_NONE,
-                                                       &error);
-        if (error == NULL)
-        {
-            screen = gtk_window_get_screen(GTK_WINDOW(window));
-            launch_context = gdk_app_launch_context_new ();
-            gdk_app_launch_context_set_screen (launch_context, screen);
-            g_app_info_launch (app_info, NULL, G_APP_LAUNCH_CONTEXT (launch_context), &error);
-            g_object_unref (launch_context);
-        }
-        if (app_info != NULL)
-            g_object_unref (app_info);
-#else
-#if GTK_CHECK_VERSION (2, 24, 0)
-        gdk_spawn_command_line_on_screen(gtk_window_get_screen(GTK_WINDOW(window)), "mate-help", &error);
-#else
-        g_spawn_command_line_async("mate-help", &error);
-#endif
-#endif
-    }
-    else
-    {
-        gtk_show_uri (gtk_window_get_screen (GTK_WINDOW (window)),
-                      "help:mate-user-guide/goscaja-1",
-                      gtk_get_current_event_time (), &error);
-    }
+    gtk_show_uri_on_window (GTK_WINDOW (window),
+                            CAJA_IS_DESKTOP_WINDOW (window)
+                               ? "help:mate-user-guide"
+                               : "help:mate-user-guide/goscaja-1",
+                            gtk_get_current_event_time (), &error);
 
     if (error)
     {
@@ -750,7 +724,7 @@ connect_proxy_cb (GtkUIManager *manager,
                   GtkWidget *proxy,
                   CajaWindow *window)
 {
-    GdkPixbuf *icon;
+    cairo_surface_t *icon;
     GtkWidget *widget;
 
     if (GTK_IS_MENU_ITEM (proxy))
@@ -761,12 +735,12 @@ connect_proxy_cb (GtkUIManager *manager,
                           G_CALLBACK (menu_item_deselect_cb), window);
 
 
-        /* This is a way to easily get pixbufs into the menu items */
+        /* This is a way to easily get surfaces into the menu items */
         icon = g_object_get_data (G_OBJECT (action), "menu-icon");
         if (icon != NULL)
         {
             gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (proxy),
-                                           gtk_image_new_from_pixbuf (icon));
+                                           gtk_image_new_from_surface (icon));
         }
     }
     if (GTK_IS_TOOL_BUTTON (proxy))
@@ -774,7 +748,7 @@ connect_proxy_cb (GtkUIManager *manager,
         icon = g_object_get_data (G_OBJECT (action), "toolbar-icon");
         if (icon != NULL)
         {
-            widget = gtk_image_new_from_pixbuf (icon);
+            widget = gtk_image_new_from_surface (icon);
             gtk_widget_show (widget);
             gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (proxy),
                                              widget);
@@ -1010,6 +984,20 @@ caja_window_initialize_menus (CajaWindow *window)
     caja_window_initialize_trash_icon_monitor (window);
 }
 
+void
+caja_window_finalize_menus (CajaWindow *window)
+{
+    CajaTrashMonitor *monitor;
+
+    monitor = caja_trash_monitor_get ();
+
+    g_signal_handlers_disconnect_by_func (monitor,
+                                          trash_state_changed_cb, window);
+
+    g_signal_handlers_disconnect_by_func (caja_preferences,
+                                          show_hidden_files_preference_callback, window);
+}
+
 static GList *
 get_extension_menus (CajaWindow *window)
 {
@@ -1018,7 +1006,7 @@ get_extension_menus (CajaWindow *window)
     GList *items;
     GList *l;
 
-    providers = caja_module_get_extensions_for_type (CAJA_TYPE_MENU_PROVIDER);
+    providers = caja_extensions_get_for_type (CAJA_TYPE_MENU_PROVIDER);
     items = NULL;
 
     slot = caja_window_get_active_slot (window);
@@ -1063,7 +1051,7 @@ add_extension_menu_items (CajaWindow *window,
 
         g_object_get (item, "menu", &menu, NULL);
 
-        action = caja_action_from_menu_item (item);
+        action = caja_action_from_menu_item (item, GTK_WIDGET (window));
         gtk_action_group_add_action_with_accel (action_group, action, NULL);
 
         path = g_build_path ("/", POPUP_PATH_EXTENSION_ACTIONS, subdirectory, NULL);
@@ -1147,14 +1135,3 @@ caja_window_load_extension_menus (CajaWindow *window)
     }
 }
 
-void
-caja_window_remove_trash_monitor_callback (CajaWindow *window)
-{
-    CajaTrashMonitor *monitor;
-
-    monitor = caja_trash_monitor_get ();
-
-    g_signal_handlers_disconnect_by_func (monitor,
-                                          trash_state_changed_cb, window);
-}
-
